@@ -30,7 +30,6 @@
 #include <string.h>
 
 #include "gupnp-didl-lite-descriptor.h"
-#include "gupnp-dlna-private.h"
 #include "xml-util.h"
 
 G_DEFINE_TYPE (GUPnPDIDLLiteDescriptor,
@@ -217,7 +216,6 @@ gupnp_didl_lite_descriptor_class_init (GUPnPDIDLLiteDescriptorClass *klass)
                                       GUPNP_TYPE_XML_DOC,
                                       G_PARAM_WRITABLE |
                                       G_PARAM_CONSTRUCT_ONLY |
-                                      G_PARAM_PRIVATE |
                                       G_PARAM_STATIC_NAME |
                                       G_PARAM_STATIC_NICK |
                                       G_PARAM_STATIC_BLURB));
@@ -333,7 +331,7 @@ gupnp_didl_lite_descriptor_new_from_xml (xmlNode     *xml_node,
  *
  * Get the pointer to desc node in XML document.
  *
- * Return value: The pointer to desc node in XML document.
+ * Returns: (transfer none): The pointer to desc node in XML document.
  **/
 xmlNode *
 gupnp_didl_lite_descriptor_get_xml_node (GUPnPDIDLLiteDescriptor *descriptor)
