@@ -49,6 +49,7 @@ struct _GUPnPDIDLLiteObjectPrivate {
 
         xmlNs *upnp_ns;
         xmlNs *dc_ns;
+        xmlNs *dlna_ns;
 };
 
 enum {
@@ -57,6 +58,7 @@ enum {
         PROP_XML_DOC,
         PROP_UPNP_NAMESPACE,
         PROP_DC_NAMESPACE,
+        PROP_DLNA_NAMESPACE,
         PROP_ID,
         PROP_PARENT_ID,
         PROP_RESTRICTED,
@@ -72,6 +74,7 @@ enum {
         PROP_DESCRIPTION,
         PROP_DATE,
         PROP_TRACK_NUMBER,
+        PROP_DLNA_MANAGED,
 };
 
 static int
@@ -120,6 +123,9 @@ gupnp_didl_lite_object_set_property (GObject      *object,
         case PROP_DC_NAMESPACE:
                 didl_object->priv->dc_ns = g_value_get_pointer (value);
                 break;
+        case PROP_DLNA_NAMESPACE:
+                didl_object->priv->dlna_ns = g_value_get_pointer (value);
+                break;
         case PROP_ID:
                 gupnp_didl_lite_object_set_id (didl_object,
                                                g_value_get_string (value));
@@ -194,6 +200,11 @@ gupnp_didl_lite_object_set_property (GObject      *object,
                                         (didl_object,
                                          g_value_get_int (value));
                 break;
+        case PROP_DLNA_MANAGED:
+                gupnp_didl_lite_object_set_dlna_managed
+                                        (didl_object,
+                                         g_value_get_flags (value));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -227,6 +238,11 @@ gupnp_didl_lite_object_get_property (GObject    *object,
                         (value,
                          gupnp_didl_lite_object_get_dc_namespace
                                 (didl_object));
+        case PROP_DLNA_NAMESPACE:
+                g_value_set_pointer
+                        (value,
+                         gupnp_didl_lite_object_get_dlna_namespace
+                                (didl_object));
                 break;
         case PROP_ID:
                 g_value_set_string
@@ -303,6 +319,11 @@ gupnp_didl_lite_object_get_property (GObject    *object,
                         (value,
                          gupnp_didl_lite_object_get_track_number (didl_object));
                 break;
+        case PROP_DLNA_MANAGED:
+                g_value_set_flags
+                        (value,
+                         gupnp_didl_lite_object_get_dlna_managed (didl_object));
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -383,7 +404,8 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
         /**
          * GUPnPDIDLLiteObject:upnp-namespace
          *
-         * Pointer to the UPnP namespace registered with the XML document                * containing this object.
+         * Pointer to the UPnP namespace registered with the XML document
+         * containing this object.
          *
          **/
         g_object_class_install_property
@@ -421,6 +443,27 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
                                        G_PARAM_STATIC_NICK |
                                        G_PARAM_STATIC_BLURB));
 
+        /**
+         * GUPnPDIDLLiteObject:dlna-namespace
+         *
+         * Pointer to the DLNA metadata namespace registered with the XML
+         * document containing this object.
+         *
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_DLNA_NAMESPACE,
+                 g_param_spec_pointer ("dlna-namespace",
+                                       "XML namespace",
+                                       "Pointer to the DLNA metadata namespace "
+                                       "registered with the XML document "
+                                       "containing this object.",
+                                       G_PARAM_READWRITE |
+                                       G_PARAM_CONSTRUCT_ONLY |
+                                       G_PARAM_STATIC_NAME |
+                                       G_PARAM_STATIC_NICK |
+                                       G_PARAM_STATIC_BLURB));
+
         /**
          * GUPnPDIDLLiteObject:id
          *
@@ -688,6 +731,24 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
                                    G_PARAM_STATIC_NAME |
                                    G_PARAM_STATIC_NICK |
                                    G_PARAM_STATIC_BLURB));
+
+        /**
+         * GUPnPDIDLLiteObject:dlna-managed
+         *
+         * The 'dlna:dlnaManaged' attribute.
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_DLNA_MANAGED,
+                 g_param_spec_flags ("dlna-managed",
+                                     "DLNAManaged",
+                                     "The 'dlna:dlnaManaged' attribute",
+                                     GUPNP_TYPE_OCM_FLAGS,
+                                     GUPNP_OCM_FLAGS_NONE,
+                                     G_PARAM_READWRITE |
+                                     G_PARAM_STATIC_NAME |
+                                     G_PARAM_STATIC_NICK |
+                                     G_PARAM_STATIC_BLURB));
 }
 
 static gboolean
@@ -754,6 +815,7 @@ get_contributor_list_by_name (GUPnPDIDLLiteObject *object,
  * @xml_doc: The reference to XML document containing this object
  * @upnp_ns: The pointer to 'upnp' namespace in XML document
  * @dc_ns: The pointer to 'dc' namespace in XML document
+ * @dlna_ns: The pointer to 'dlna' namespace in XML document
  *
  * Creates a new #GUPnPDIDLLiteObject for the @xml_node.
  *
@@ -763,12 +825,14 @@ GUPnPDIDLLiteObject *
 gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
                                      GUPnPXMLDoc *xml_doc,
                                      xmlNs       *upnp_ns,
-                                     xmlNs       *dc_ns)
+                                     xmlNs       *dc_ns,
+                                     xmlNs       *dlna_ns)
 {
         g_return_val_if_fail (xml_node != NULL, NULL);
         g_return_val_if_fail (xml_node->name != NULL, NULL);
         g_return_val_if_fail (upnp_ns != NULL, NULL);
         g_return_val_if_fail (dc_ns != NULL, NULL);
+        g_return_val_if_fail (dlna_ns != NULL, NULL);
 
         if (g_ascii_strcasecmp ((char *) xml_node->name, "container") == 0)
                 return g_object_new (GUPNP_TYPE_DIDL_LITE_CONTAINER,
@@ -776,6 +840,7 @@ gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
                                      "xml-doc", xml_doc,
                                      "upnp-namespace", upnp_ns,
                                      "dc-namespace", dc_ns,
+                                     "dlna-namespace", dlna_ns,
                                      NULL);
         else if (g_ascii_strcasecmp ((char *) xml_node->name, "item") == 0)
                 return g_object_new (GUPNP_TYPE_DIDL_LITE_ITEM,
@@ -783,6 +848,7 @@ gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
                                      "xml-doc", xml_doc,
                                      "upnp-namespace", upnp_ns,
                                      "dc-namespace", dc_ns,
+                                     "dlna-namespace", dlna_ns,
                                      NULL);
         else
                 return NULL;
@@ -794,7 +860,7 @@ gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
  *
  * Get the pointer to object node in XML document.
  *
- * Return value: The pointer to object node in XML document.
+ * Returns: (transfer none): The pointer to object node in XML document.
  **/
 xmlNode *
 gupnp_didl_lite_object_get_xml_node (GUPnPDIDLLiteObject *object)
@@ -810,7 +876,7 @@ gupnp_didl_lite_object_get_xml_node (GUPnPDIDLLiteObject *object)
  *
  * Get the pointer to the UPnP namespace registered with the XML document.
  *
- * Return value: The pointer to UPnP namespace in XML document.
+ * Returns: (transfer none): The pointer to UPnP namespace in XML document.
  **/
 xmlNsPtr
 gupnp_didl_lite_object_get_upnp_namespace (GUPnPDIDLLiteObject *object)
@@ -827,7 +893,7 @@ gupnp_didl_lite_object_get_upnp_namespace (GUPnPDIDLLiteObject *object)
  * Get the pointer to the DublinCore namespace registered with the XML document
  * containing this object.
  *
- * Return value: The pointer to DublinCore namespace in XML document.
+ * Returns: (transfer none): The pointer to DublinCore namespace in XML document.
  **/
 xmlNsPtr
 gupnp_didl_lite_object_get_dc_namespace (GUPnPDIDLLiteObject *object)
@@ -854,6 +920,23 @@ gupnp_didl_lite_object_get_upnp_class (GUPnPDIDLLiteObject *object)
                                                    "class");
 }
 
+/**
+ * gupnp_didl_lite_object_get_dlna_namespace:
+ * @object: The #GUPnPDIDLLiteObject
+ *
+ * Get the pointer to the DLNA metadata namespace registered with the XML
+ * document containing this object.
+ *
+ * Returns: (transfer none): The pointer to DLNA namespace in XML document.
+ **/
+xmlNsPtr
+gupnp_didl_lite_object_get_dlna_namespace (GUPnPDIDLLiteObject *object)
+{
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object), NULL);
+
+        return object->priv->dlna_ns;
+}
+
 /**
  * gupnp_didl_lite_object_get_id
  * @object: #GUPnPDIDLLiteObject
@@ -895,9 +978,9 @@ gupnp_didl_lite_object_get_parent_id (GUPnPDIDLLiteObject *object)
  *
  * Use this function to retreive property nodes by name.
  *
- * Return value: (element-type utf8) (transfer none): The list of property nodes
- * by the name @property_name belonging to @object, or %NULL. #g_list_free the
- * returned list after usage but do not modify the contents.
+ * Return value: (element-type xmlNode*) (transfer container): The list of
+ * property nodes by the name @property_name belonging to @object, or %NULL.
+ * #g_list_free the returned list after usage but do not modify the contents.
  **/
 GList *
 gupnp_didl_lite_object_get_properties (GUPnPDIDLLiteObject *object,
@@ -969,7 +1052,8 @@ gupnp_didl_lite_object_get_creator (GUPnPDIDLLiteObject *object)
  *
  * Get the creators of the @object.
  *
- * Return value: The list of creators belonging to @object, or %NULL.
+ * Returns: (element-type GUPnPDIDLLiteContributor*) (transfer full): The list
+ * of creators belonging to @object, or %NULL.
  * #g_list_free the returned list after usage and unref each object in it.
  **/
 GList *
@@ -1006,7 +1090,8 @@ gupnp_didl_lite_object_get_artist (GUPnPDIDLLiteObject *object)
  *
  * Get the artists of the @object.
  *
- * Return value: The list of artists belonging to @object, or %NULL.
+ * Returns: (element-type GUPnPDIDLLiteContributor*) (transfer full): The list
+ * of artists belonging to @object, or %NULL.
  * #g_list_free the returned list after usage and unref each object in it.
  **/
 GList *
@@ -1014,7 +1099,7 @@ gupnp_didl_lite_object_get_artists (GUPnPDIDLLiteObject *object)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object), NULL);
 
-        return get_contributor_list_by_name (object, "artists");
+        return get_contributor_list_by_name (object, "artist");
 }
 
 /**
@@ -1042,7 +1127,8 @@ gupnp_didl_lite_object_get_author (GUPnPDIDLLiteObject *object)
  *
  * Get the authors of the @object.
  *
- * Return value: The list of authors belonging to @object, or %NULL.
+ * Returns: (element-type GUPnPDIDLLiteContributor*) (transfer full): The list
+ * of authors belonging to @object, or %NULL.
  * #g_list_free the returned list after usage and unref each object in it.
  **/
 GList *
@@ -1050,7 +1136,7 @@ gupnp_didl_lite_object_get_authors (GUPnPDIDLLiteObject *object)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object), NULL);
 
-        return get_contributor_list_by_name (object, "authors");
+        return get_contributor_list_by_name (object, "author");
 }
 
 /**
@@ -1059,7 +1145,8 @@ gupnp_didl_lite_object_get_authors (GUPnPDIDLLiteObject *object)
  *
  * Get the descriptors of the @object.
  *
- * Return value: The list of descriptors belonging to @object, or %NULL.
+ * Returns: (element-type GUPnPDIDLLiteDescriptor*) (transfer full): The list of
+ * descriptors belonging to @object, or %NULL.
  * #g_list_free the returned list after usage and unref each object in it.
  **/
 GList *
@@ -1216,15 +1303,43 @@ gupnp_didl_lite_object_get_track_number (GUPnPDIDLLiteObject *object)
         return atoi (str);
 }
 
+/**
+ * gupnp_didl_lite_object_get_dlna_managed:
+ * @object: #GUPnPDIDLLiteObject
+ *
+ * Get the 'dlna:dlnaManaged' attribute of the @object.
+ *
+ * Return value: The 'dlna:dlnaManaged' attribute of the @object.
+ **/
+GUPnPOCMFlags
+gupnp_didl_lite_object_get_dlna_managed (GUPnPDIDLLiteObject *object)
+{
+        const char *str;
+        GUPnPOCMFlags dlna_managed;
+
+        g_return_val_if_fail (object != NULL, GUPNP_OCM_FLAGS_NONE);
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object),
+                              GUPNP_OCM_FLAGS_NONE);
+
+        str = xml_util_get_attribute_content (object->priv->xml_node,
+                                              "dlnaManaged");
+        if (str == NULL)
+                return GUPNP_OCM_FLAGS_NONE;
+
+        sscanf (str, "%08x", &dlna_managed);
+
+        return dlna_managed;
+}
+
 /**
  * gupnp_didl_lite_object_get_resources:
  * @object: #GUPnPDIDLLiteObject
  *
  * Use this function to retreive resources from the @object.
  *
- * Return value: (element-type GUPnPDIDLLiteResource) (transfer full): The list of resources belonging to 
-@object, or %NULL.
- * #g_list_free the returned list after usage and unref each resource in it.
+ * Return value: (element-type GUPnPDIDLLiteResource*) (transfer full): The list
+ *               of resources belonging to  @object, or %NULL. #g_list_free the
+ *               returned list after usage and unref each resource in it.
  **/
 GList *
 gupnp_didl_lite_object_get_resources (GUPnPDIDLLiteObject *object)
@@ -1271,7 +1386,7 @@ gupnp_didl_lite_object_get_resources (GUPnPDIDLLiteObject *object)
  * If @lenient is #TRUE, the first resource in the list is returned instead of
  * %NULL if none of resources and protocols are found to be compatible.
  *
- * Return value: The resource belonging to @object that is comaptible with
+ * Returns: (transfer full): The resource belonging to @object that is comaptible with
  * any of the protocols specified in @sink_protocol_info, or %NULL. Unref after
  * usage.
  **/
@@ -1480,7 +1595,7 @@ gupnp_didl_lite_object_set_creator (GUPnPDIDLLiteObject *object,
  * Add a new creator node to the @object and return the associated
  * #GUPnPDIDLLiteContributor object.
  *
- * Return value: A new #GUPnPDIDLLiteContributor object. Unref after usage.
+ * Returns: (transfer full): A new #GUPnPDIDLLiteContributor object. Unref after usage.
  **/
 GUPnPDIDLLiteContributor *
 gupnp_didl_lite_object_add_creator (GUPnPDIDLLiteObject *object)
@@ -1532,7 +1647,7 @@ gupnp_didl_lite_object_set_artist (GUPnPDIDLLiteObject *object,
  * Add a new Artist node to the @object and return the associated
  * #GUPnPDIDLLiteContributor object.
  *
- * Return value: A new #GUPnPDIDLLiteContributor object. Unref after usage.
+ * Returns: (transfer full): A new #GUPnPDIDLLiteContributor object. Unref after usage.
  **/
 GUPnPDIDLLiteContributor *
 gupnp_didl_lite_object_add_artist (GUPnPDIDLLiteObject *object)
@@ -1583,7 +1698,7 @@ gupnp_didl_lite_object_set_author (GUPnPDIDLLiteObject *object,
  * Add a new author node to the @object and return the associated
  * #GUPnPDIDLLiteContributor object.
  *
- * Return value: A new #GUPnPDIDLLiteContributor object. Unref after usage.
+ * Returns: (transfer full): A new #GUPnPDIDLLiteContributor object. Unref after usage.
  **/
 GUPnPDIDLLiteContributor *
 gupnp_didl_lite_object_add_author (GUPnPDIDLLiteObject *object)
@@ -1683,7 +1798,6 @@ gupnp_didl_lite_object_set_album_art (GUPnPDIDLLiteObject *object,
                                       const char          *album_art)
 {
         xmlNode *node;
-        xmlNs *dlna_ns;
 
         g_return_if_fail (object != NULL);
         g_return_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object));
@@ -1693,13 +1807,8 @@ gupnp_didl_lite_object_set_album_art (GUPnPDIDLLiteObject *object,
                                    object->priv->xml_doc->doc,
                                    "albumArtURI",
                                    album_art);
-
-        dlna_ns = xmlNewNs (node,
-                            (const unsigned char *)
-                            "urn:schemas-dlna-org:metadata-2-0/",
-                            (const unsigned char *) "dlna");
-        xmlNewNsProp (node,
-                      dlna_ns,
+        xmlSetNsProp (node,
+                      object->priv->dlna_ns,
                       (const unsigned char *) "profileID",
                       (const unsigned char *) "JPEG_TN");
 
@@ -1779,13 +1888,39 @@ gupnp_didl_lite_object_set_track_number (GUPnPDIDLLiteObject *object,
         g_object_notify (G_OBJECT (object), "track-number");
 }
 
+/**
+ * gupnp_didl_lite_object_set_dlna_managed:
+ * @object: #GUPnPDIDLLiteObject
+ * @dlna_managed: The #GUPnPOCMFlags.
+ *
+ * Set the 'dlna:dlnaManaged' attribute of the @object to @dlna_managed.
+ **/
+void
+gupnp_didl_lite_object_set_dlna_managed (GUPnPDIDLLiteObject *object,
+                                         GUPnPOCMFlags        dlna_managed)
+{
+        char *str;
+
+        g_return_if_fail (object != NULL);
+        g_return_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object));
+
+        str = g_strdup_printf ("%08x", dlna_managed);
+        xmlSetNsProp (object->priv->xml_node,
+                      object->priv->dlna_ns,
+                      (const unsigned char *) "dlnaManaged",
+                      (const unsigned char *) str);
+        g_free (str);
+
+        g_object_notify (G_OBJECT (object), "dlna-managed");
+}
+
 /**
  * gupnp_didl_lite_object_add_resource:
  * @object: A #GUPnPDIDLLiteObject
  *
  * Creates a new resource, attaches it to @object and returns it.
  *
- * Return value: A new #GUPnPDIDLLiteResource object. Unref after usage.
+ * Returns: (transfer full): A new #GUPnPDIDLLiteResource object. Unref after usage.
  **/
 GUPnPDIDLLiteResource *
 gupnp_didl_lite_object_add_resource (GUPnPDIDLLiteObject *object)
@@ -1809,7 +1944,7 @@ gupnp_didl_lite_object_add_resource (GUPnPDIDLLiteObject *object)
  *
  * Creates a new descriptor, attaches it to @object and returns it.
  *
- * Return value: A new #GUPnPDIDLLiteDescriptor object. Unref after usage.
+ * Returns: (transfer full): A new #GUPnPDIDLLiteDescriptor object. Unref after usage.
  **/
 GUPnPDIDLLiteDescriptor *
 gupnp_didl_lite_object_add_descriptor (GUPnPDIDLLiteObject *object)
